ChannelMessage

Struct ChannelMessage 

pub struct ChannelMessage {
    pub chat_id: i64,
    pub sender_id: i64,
    pub sender_name: CompactString,
    pub is_bot: bool,
    pub is_group: bool,
    pub content: String,
    pub attachments: Vec<Attachment>,
    pub reply_to: Option<i32>,
    pub timestamp: u64,
}
A message received from or sent to a channel.

Fields

chat_id: i64

Platform chat/channel ID.

sender_id: i64

Platform sender user ID.

sender_name: CompactString

Display name of the sender.

is_bot: bool

Whether the sender is a bot.

is_group: bool

Whether this message is from a group chat (vs DM).

content: String

Message text content.

attachments: Vec<Attachment>

Attached files or media.

reply_to: Option<i32>

Message ID being replied to, if any.

timestamp: u64

Unix timestamp when the message was created.